@@ -45,6 +45,7 @@ class Oracle(Dialect):
     NULL_ORDERING = "nulls_are_large"
     ON_CONDITION_EMPTY_BEFORE_ERROR = False
     ALTER_TABLE_ADD_REQUIRED_FOR_EACH_COLUMN = False
+    DISABLES_ALIAS_REF_EXPANSION = True
 
     # See section 8: https://docs.oracle.com/cd/A97630_01/server.920/a96540/sql_elements9a.htm
     NORMALIZATION_STRATEGY = NormalizationStrategy.UPPERCASE
@@ -72,6 +73,18 @@ class Oracle(Dialect):
         "FF6": "%f",  # only 6 digits are supported in python formats
     }
 
+    PSEUDOCOLUMNS = {"ROWNUM", "ROWID", "OBJECT_ID", "OBJECT_VALUE", "LEVEL"}
+
+    def quote_identifier(self, expression: E, identify: bool = True) -> E:
+        # Disable quoting for pseudocolumns as it may break queries e.g
+        # `WHERE "ROWNUM" = ...` does not work but `WHERE ROWNUM = ...` does
+        if isinstance(expression, exp.Identifier) and isinstance(
+            expression.parent, exp.Pseudocolumn
+        ):
+            return expression
+
+        return super().quote_identifier(expression, identify=identify)
+
     class Tokenizer(tokens.Tokenizer):
         VAR_SINGLE_TOKENS = {"@", "$", "#"}
 
@@ -264,6 +277,24 @@ class Oracle(Dialect):
         def _parse_connect_with_prior(self):
             return self._parse_assignment()
 
+        def _parse_insert_table(self) -> t.Optional[exp.Expression]:
+            # Oracle does not use AS for INSERT INTO alias
+            # https://docs.oracle.com/en/database/oracle/oracle-database/18/sqlrf/INSERT.html
+            # Parse table parts without schema to avoid parsing the alias with its columns
+            this = self._parse_table_parts(schema=True)
+
+            if isinstance(this, exp.Table):
+                alias_name = self._parse_id_var(any_token=False)
+                if alias_name:
+                    this.set("alias", exp.TableAlias(this=alias_name))
+
+                this.set("partition", self._parse_partition())
+
+                # Now parse the schema (column list) if present
+                return self._parse_schema(this=this)
+
+            return this
+
     class Generator(generator.Generator):
         LOCKING_READS_SUPPORTED = True
         JOIN_HINTS = False
@@ -307,7 +338,6 @@ class Oracle(Dialect):
             ),
             exp.DateTrunc: lambda self, e: self.func("TRUNC", e.this, e.unit),
             exp.EuclideanDistance: rename_func("L2_DISTANCE"),
-            exp.Group: transforms.preprocess([transforms.unalias_group]),
             exp.ILike: no_ilike_sql,
             exp.LogicalOr: rename_func("MAX"),
             exp.LogicalAnd: rename_func("MIN"),
