@@ -1822,23 +1822,27 @@ BOOLEAN;
 
 # dialect: snowflake
 ARRAY_AGG(tbl.bin_col);
-ARRAY<BINARY>;
+ARRAY;
 
 # dialect: snowflake
 ARRAY_AGG(tbl.bool_col);
-ARRAY<BOOLEAN>;
+ARRAY;
 
 # dialect: snowflake
 ARRAY_AGG(tbl.date_col);
-ARRAY<DATE>;
+ARRAY;
 
 # dialect: snowflake
 ARRAY_AGG(tbl.double_col);
-ARRAY<DOUBLE>;
+ARRAY;
 
 # dialect: snowflake
 ARRAY_AGG(tbl.str_col);
-ARRAY<VARCHAR>;
+ARRAY;
+
+# dialect: snowflake
+ARRAY_UNION_AGG(tbl.array_col);
+ARRAY;
 
 # dialect: snowflake
 CHARINDEX('world', 'hello world');
@@ -1884,6 +1888,18 @@ VARCHAR;
 CHR(8364);
 VARCHAR;
 
+# dialect: snowflake
+CHECK_JSON('{"key": "value", "array": [1, 2, 3]}');
+VARCHAR;
+
+# dialect: snowflake
+CHECK_XML('<root><key attribute="attr">value</key></root>');
+VARCHAR;
+
+# dialect: snowflake
+CHECK_XML('<root><key attribute="attr">value</key></root>', TRUE);
+VARCHAR;
+
 # dialect: snowflake
 COLLATE('hello', 'utf8');
 VARCHAR;
@@ -1912,10 +1928,22 @@ VARCHAR;
 COALESCE(CAST('2024-01-01' AS DATE), CAST('2024-12-31' AS DATE));
 DATE;
 
+# dialect: snowflake
+CAST(1.5 AS DECFLOAT);
+DECFLOAT;
+
 # dialect: snowflake
 COALESCE(TRUE, FALSE);
 BOOLEAN;
 
+# dialect: snowflake
+COUNT(*);
+BIGINT;
+
+# dialect: snowflake
+COUNT(DISTINCT tbl.str_col);
+BIGINT;
+
 # dialect: snowflake
 COMPRESS('Hello World', 'SNAPPY');
 BINARY;
@@ -2376,6 +2404,10 @@ VARCHAR;
 GREATEST_IGNORE_NULLS(CAST('2023-01-01' AS DATE), CAST('2023-01-02' AS DATE));
 DATE;
 
+# dialect: snowflake
+HASH_AGG(tbl.str_col);
+DECIMAL(19, 0);
+
 # dialect: snowflake
 LEAST_IGNORE_NULLS(1, 2, 3);
 INT;
@@ -2612,6 +2644,14 @@ BIGINT;
 RANDOM(123);
 BIGINT;
 
+# dialect: snowflake
+RANDSTR(123, 456);
+VARCHAR;
+
+# dialect: snowflake
+RANDSTR(123, RANDOM());
+VARCHAR;
+
 # dialect: snowflake
 RADIANS(tbl.double_col);
 DOUBLE;
@@ -2644,6 +2684,18 @@ VARCHAR;
 MINUTE(CAST('08:50:57' AS TIME));
 INT;
 
+# dialect: snowflake
+MEDIAN(2.71::FLOAT);
+FLOAT;
+
+# dialect: snowflake
+MEDIAN(tbl.bigint_col) OVER (PARTITION BY 1);
+DECIMAL(38, 3);
+
+# dialect: snowflake
+MEDIAN(CAST(100 AS DECIMAL(10,2)));
+DECIMAL(13, 5);
+
 # dialect: snowflake
 MONTHNAME(CAST('2024-05-09' AS DATE));
 VARCHAR;
@@ -2652,6 +2704,10 @@ VARCHAR;
 MONTHNAME(CAST('2024-05-09 08:50:57' AS TIMESTAMP));
 VARCHAR;
 
+# dialect: snowflake
+NORMAL(0, 1, RANDOM());
+DOUBLE;
+
 # dialect: snowflake
 NVL2(col1, col2, col3);
 UNKNOWN;
@@ -2744,6 +2800,18 @@ DOUBLE;
 REGR_AVGY(tbl.double_col, tbl.double_col);
 DOUBLE;
 
+# dialect: snowflake
+REGR_SLOPE(tbl.double_col, tbl.double_col);
+DOUBLE;
+
+# dialect: snowflake
+REGR_SLOPE(tbl.double_col, tbl.double_col) OVER (PARTITION BY 1);
+DOUBLE;
+
+# dialect: snowflake
+REGR_SLOPE(tbl.int_col, tbl.int_col);
+DOUBLE;
+
 # dialect: snowflake
 REGR_VALX(1.0, 2.0);
 DOUBLE;
@@ -2928,6 +2996,222 @@ BIGINT;
 ROUND(tbl.double_col, 0, 'HALF_TO_EVEN');
 DOUBLE;
 
+# dialect: snowflake
+ROUND(CAST(3.14 AS FLOAT), 1);
+FLOAT;
+
+# dialect: snowflake
+ROUND(CAST(1.5 AS DECFLOAT), 0);
+DECFLOAT;
+
+# dialect: snowflake
+FLOOR(CAST(3.7 AS DECFLOAT));
+DECFLOAT;
+
+# dialect: snowflake
+FLOOR(CAST(3.7 AS FLOAT));
+FLOAT;
+
+# dialect: snowflake
+FLOOR(tbl.double_col);
+DOUBLE;
+
+# dialect: snowflake
+CEIL(CAST(3.2 AS DECFLOAT));
+DECFLOAT;
+
+# dialect: snowflake
+CEIL(CAST(3.2 AS FLOAT));
+FLOAT;
+
+# dialect: snowflake
+CEIL(tbl.double_col);
+DOUBLE;
+
+# dialect: snowflake
+SQRT(CAST(16 AS DECFLOAT));
+DECFLOAT;
+
+# dialect: snowflake
+SQRT(CAST(16 AS DOUBLE));
+DOUBLE;
+
+# dialect: snowflake
+EXP(CAST(2 AS DECFLOAT));
+DECFLOAT;
+
+# dialect: snowflake
+EXP(CAST(2 AS DOUBLE));
+DOUBLE;
+
+# dialect: snowflake
+LN(CAST(10 AS DECFLOAT));
+DECFLOAT;
+
+# dialect: snowflake
+LN(CAST(10 AS DOUBLE));
+DOUBLE;
+
+# dialect: snowflake
+LOG(CAST(100 AS DECFLOAT), 10);
+DECFLOAT;
+
+# dialect: snowflake
+LOG(CAST(100 AS DOUBLE), 10);
+DOUBLE;
+
+# dialect: snowflake
+POW(CAST(2 AS DECFLOAT), 3);
+DECFLOAT;
+
+# dialect: snowflake
+POW(CAST(2 AS DOUBLE), 3);
+DOUBLE;
+
+# dialect: snowflake
+SIN(CAST(1.5 AS DECFLOAT));
+DECFLOAT;
+
+# dialect: snowflake
+SIN(CAST(1.5 AS DOUBLE));
+DOUBLE;
+
+# dialect: snowflake
+COS(CAST(1.5 AS DECFLOAT));
+DECFLOAT;
+
+# dialect: snowflake
+COS(CAST(1.5 AS DOUBLE));
+DOUBLE;
+
+# dialect: snowflake
+TAN(CAST(1.5 AS DECFLOAT));
+DECFLOAT;
+
+# dialect: snowflake
+TAN(CAST(1.5 AS DOUBLE));
+DOUBLE;
+
+# dialect: snowflake
+COT(CAST(1.5 AS DECFLOAT));
+DECFLOAT;
+
+# dialect: snowflake
+COT(CAST(1.5 AS DOUBLE));
+DOUBLE;
+
+# dialect: snowflake
+ASIN(CAST(0.5 AS DECFLOAT));
+DECFLOAT;
+
+# dialect: snowflake
+ASIN(CAST(0.5 AS DOUBLE));
+DOUBLE;
+
+# dialect: snowflake
+ACOS(CAST(0.5 AS DECFLOAT));
+DECFLOAT;
+
+# dialect: snowflake
+ACOS(CAST(0.5 AS DOUBLE));
+DOUBLE;
+
+# dialect: snowflake
+ATAN(CAST(1 AS DECFLOAT));
+DECFLOAT;
+
+# dialect: snowflake
+ATAN(CAST(1 AS DOUBLE));
+DOUBLE;
+
+# dialect: snowflake
+ATAN2(CAST(1 AS DECFLOAT), 1);
+DECFLOAT;
+
+# dialect: snowflake
+ATAN2(CAST(1 AS DOUBLE), 1);
+DOUBLE;
+
+# dialect: snowflake
+DEGREES(CAST(3.14159 AS DECFLOAT));
+DECFLOAT;
+
+# dialect: snowflake
+DEGREES(CAST(3.14159 AS DOUBLE));
+DOUBLE;
+
+# dialect: snowflake
+RADIANS(CAST(180 AS DECFLOAT));
+DECFLOAT;
+
+# dialect: snowflake
+RADIANS(CAST(180 AS DOUBLE));
+DOUBLE;
+
+# dialect: snowflake
+TANH(CAST(1 AS DECFLOAT));
+DECFLOAT;
+
+# dialect: snowflake
+TANH(CAST(1 AS DOUBLE));
+DOUBLE;
+
+# dialect: snowflake
+TO_DECFLOAT('123.456');
+DECFLOAT;
+
+# dialect: snowflake
+TO_DECFLOAT('123.456', '999.999');
+DECFLOAT;
+
+# dialect: snowflake
+TRY_TO_DECFLOAT('123.456');
+DECFLOAT;
+
+# dialect: snowflake
+TRY_TO_DECFLOAT('invalid');
+DECFLOAT;
+
+# dialect: snowflake
+ABS(CAST(-123.456 AS DECFLOAT));
+DECFLOAT;
+
+# dialect: snowflake
+ABS(CAST(-123.456 AS FLOAT));
+FLOAT;
+
+# dialect: snowflake
+MOD(CAST(10 AS DECFLOAT), 3);
+DECFLOAT;
+
+# dialect: snowflake
+MOD(CAST(10 AS FLOAT), 3);
+FLOAT;
+
+# dialect: snowflake
+GREATEST(CAST(1 AS FLOAT), CAST(2 AS DECFLOAT));
+DECFLOAT;
+
+# dialect: snowflake
+GREATEST(CAST(2 AS DECFLOAT), CAST(2 AS DECFLOAT));
+DECFLOAT;
+
+# dialect: snowflake
+GREATEST(CAST(1 AS FLOAT), CAST(2 AS FLOAT));
+FLOAT;
+
+# dialect: snowflake
+LEAST(CAST(1 AS FLOAT), CAST(2 AS DECFLOAT));
+DECFLOAT;
+
+# dialect: snowflake
+LEAST(CAST(1 AS DECFLOAT), CAST(2 AS DECFLOAT));
+DECFLOAT;
+
+# dialect: snowflake
+LEAST(CAST(1 AS FLOAT), CAST(2 AS FLOAT));
+FLOAT;
+
 # dialect: snowflake
 SECOND(CAST('08:50:57' AS TIME));
 INT;
@@ -3164,6 +3448,10 @@ BOOLEAN;
 SEARCH(line, 'king', ANALYZER => 'UNICODE_ANALYZER', SEARCH_MODE => 'AND');
 BOOLEAN;
 
+# dialect: snowflake
+SEARCH_IP(col, '192.168.0.0');
+BOOLEAN;
+
 # dialect: snowflake
 STRTOK_TO_ARRAY('a,b,c', ',');
 ARRAY;
@@ -3416,13 +3704,37 @@ DOUBLE;
 PARSE_IP('192.168.1.1', 'INET');
 OBJECT;
 
+# dialect: snowflake
+MAX(tbl.bigint_col);
+BIGINT;
+
+# dialect: snowflake
+MAX(tbl.int_col);
+INT;
+
+# dialect: snowflake
+MAX(tbl.double_col);
+DOUBLE;
+
+# dialect: snowflake
+MAX(tbl.str_col);
+VARCHAR;
+
+# dialect: snowflake
+MAX(tbl.date_col);
+DATE;
+
+# dialect: snowflake
+MAX(tbl.timestamp_col);
+TIMESTAMP;
+
 # dialect: snowflake
 MAX_BY('foo', tbl.bigint_col);
 VARCHAR;
 
 # dialect: snowflake
 MAX_BY('foo', tbl.bigint_col, 3);
-ARRAY<VARCHAR>;
+ARRAY;
 
 # dialect: snowflake
 MIN_BY('foo', tbl.bigint_col);
@@ -3430,7 +3742,7 @@ VARCHAR;
 
 # dialect: snowflake
 MIN_BY('foo', tbl.bigint_col, 3);
-ARRAY<VARCHAR>;
+ARRAY;
 
 # dialect: snowflake
 APPROX_PERCENTILE(tbl.bigint_col, 0.5);
@@ -3460,6 +3772,22 @@ DOUBLE;
 APPROX_TOP_K_ACCUMULATE(tbl.str_col, 10);
 OBJECT;
 
+# dialect: snowflake
+APPROX_TOP_K_COMBINE(tbl.state_col, 10);
+OBJECT;
+
+# dialect: snowflake
+APPROX_TOP_K_COMBINE(tbl.state_col);
+OBJECT;
+
+# dialect: snowflake
+APPROX_TOP_K_ESTIMATE(tbl.state_col, 4);
+ARRAY;
+
+# dialect: snowflake
+APPROX_TOP_K_ESTIMATE(tbl.state_col);
+ARRAY;
+
 # dialect: snowflake
 APPROX_COUNT_DISTINCT(tbl.str_col);
 BIGINT;
@@ -3508,6 +3836,50 @@ ARRAY;
 APPROX_TOP_K(tbl.str_col, 5, 1000);
 ARRAY;
 
+# dialect: snowflake
+MINHASH(5, tbl.int_col);
+VARIANT;
+
+# dialect: snowflake
+MINHASH(5, tbl.int_col, tbl.str_col);
+VARIANT;
+
+# dialect: snowflake
+MINHASH(5, *);
+VARIANT;
+
+# dialect: snowflake
+MINHASH_COMBINE(tbl.variant_col);
+VARIANT;
+
+# dialect: snowflake
+APPROXIMATE_SIMILARITY(tbl.variant_col);
+DOUBLE;
+
+# dialect: snowflake
+APPROXIMATE_JACCARD_INDEX(tbl.variant_col);
+DOUBLE;
+
+# dialect: snowflake
+MIN(tbl.double_col);
+DOUBLE;
+
+# dialect: snowflake
+MIN(tbl.int_col);
+INT;
+
+# dialect: snowflake
+MIN(tbl.bigint_col);
+BIGINT;
+
+# dialect: snowflake
+MIN(CAST(100 AS DECIMAL(10,2)));
+DECIMAL(10, 2);
+
+# dialect: snowflake
+MIN(tbl.bigint_col) OVER (PARTITION BY 1);
+BIGINT;
+
 --------------------------------------
 -- T-SQL
 --------------------------------------
